<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=hu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-hu',
	'0_langue' => 'Magyar [hu]',
	'0_liste' => 'spip-hu@rezo.net',
	'0_mainteneur' => 'trucy@freemail.huEcker Gábor (ecker.gabor@ecker.t-online.hu)',

	// A
	'access_interface_graphique' => 'Vissza a teljes grafikus felületre',
	'access_mode_texte' => 'Egyszerűsített szöveges felület megjelenítése',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Cikk módosítása',
	'admin_modifier_auteur' => 'Szerző módosítása',
	'admin_modifier_breve' => 'Hír szerkesztése',
	'admin_modifier_mot' => 'Kulcsszó módosítása',
	'admin_modifier_rubrique' => 'Rovat módosítása',
	'admin_recalculer' => 'Oldal frissítése',
	'afficher_trad' => 'fordítások megjelenítése',
	'alerte_maj_impossible' => '<b>Hiba !</b> A SQL adatbázis frissítése a @version@ verzió felé nem lehtséges, talán adatbázishoz való módosítási jogosultság miatt. Ilyenkor a tárhely adminisztrátorához kell fordulni.',
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifié par ailleurs. La valeur actuelle est :', # MODIF
	'analyse_xml' => 'XML elemzés',
	'annuler' => 'Mégsem',
	'antispam_champ_vide' => 'Kérjük, hagyja üresen ezt a mezőt:',
	'articles_recents' => 'Legújabb cikkek',
	'avis_archive_incorrect' => 'Az archiválási fájl nem SPIP típusú',
	'avis_archive_invalide' => 'Az archválási fájl érvénytelen',
	'avis_attention' => 'Vigyázat !',
	'avis_champ_incorrect_type_objet' => 'Érvénytelen mezőnév @name@ a(z) @type@ típusú objektumhoz',
	'avis_colonne_inexistante' => 'A(z) @col@ nevű oszlop nem létezik',
	'avis_erreur' => 'Hiba: lásd lejjebb',
	'avis_erreur_connexion' => 'Csatlakozási hiba',
	'avis_erreur_cookie' => 'Cookie hiba',
	'avis_erreur_fonction_contexte' => 'Programozási hiba. Ezt a függvényt nem lehet hívni e körülmények között.',
	'avis_erreur_mysql' => 'SQL hiba',
	'avis_erreur_sauvegarde' => 'Hiba a mentés során (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Probléma a privát zónába lépéskor',

	// B
	'barre_a_accent_grave' => 'Francia ékezetes A nagybetű beszúrása',
	'barre_aide' => 'Használjon a nyomdai jelöléseket, hogy szépítse az írásképet',
	'barre_e_accent_aigu' => 'Francia ékezetes E nagybetű beszúrása',
	'barre_eo' => 'E betű beszúrása az O-ban',
	'barre_eo_maj' => 'E betű beszúrása az O nagybetűbe',
	'barre_euro' => 'Az € karakter beszúrása',
	'barre_gras' => '{{félkövér stílus}} alkalmazása',
	'barre_guillemets' => '« idezőjelekbe »',
	'barre_guillemets_simples' => 'idézőjelekbe',
	'barre_intertitre' => '{{{közcím stílus}}} alkalmazása',
	'barre_italic' => '{dőlt stílus} alkalmazása',
	'barre_lien' => 'Hiperhivatkozás beszúrása [link szövege->http://...]',
	'barre_lien_input' => 'Kérjük, adja meg a hivatkozás célját. (Beírhat egy webcímet http://www.mysite.com formátumban, vagy egyszerűen megadhatja az egyik cikk számát ezen az oldalon.)',
	'barre_note' => '[[Lábjegyzet stílus]] alkalmazása',
	'barre_paragraphe' => 'Új bekezdés',
	'barre_quote' => '<quote>Üzenet idézése</quote>',
	'bouton_changer' => 'Módosítás',
	'bouton_chercher' => 'Keresés',
	'bouton_choisir' => 'Kiválasztás',
	'bouton_download' => 'Letöltés',
	'bouton_enregistrer' => 'Mentés',
	'bouton_radio_desactiver_messagerie_interne' => 'Belső üzenetek letiltása',
	'bouton_radio_envoi_annonces' => 'Szerkesztői közlemény küldése',
	'bouton_radio_non_envoi_annonces' => 'Ne küldjön közleményeket',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Ne küldjön listát a legújabb hírekről',
	'bouton_recharger_page' => 'az oldal újratöltése',
	'bouton_telecharger' => 'Feltöltés',
	'bouton_upload' => 'Feltöltés', # MODIF
	'bouton_valider' => 'Rendben',

	// C
	'cal_apresmidi' => 'délután',
	'cal_jour_entier' => 'egész nap',
	'cal_matin' => 'délelőtt',
	'cal_par_jour' => 'napi naptár',
	'cal_par_mois' => 'havi naptár',
	'cal_par_semaine' => 'heti naptár',
	'choix_couleur_interface' => 'szín',
	'choix_interface' => 'választott interfész',
	'colonne' => 'Oszlop',
	'confirm_changer_statut' => 'Vigyázat, az elem státuszának változtatását kérte. Kívánja folytatni?',
	'correcte' => 'helyes',

	// D
	'date_aujourdhui' => 'ma',
	'date_avant_jc' => 'Kr.e.',
	'date_dans' => '@delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'holnap',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_jour_heure' => '@jour@ @heure@',
	'date_fmt_jour_mois' => '@nommois@ @jour@',
	'date_fmt_jour_mois_annee' => '@annee@. @nommois@ @jour@  ',
	'date_fmt_mois_annee' => '@annee@. @nommois@',
	'date_fmt_nomjour_date' => '@date@ @nomjour@',
	'date_heures' => 'óra',
	'date_hier' => 'tegnap',
	'date_il_y_a' => 'ezelőtt @delai@',
	'date_jnum1' => '1.',
	'date_jnum10' => '10.',
	'date_jnum11' => '11.',
	'date_jnum12' => '12.',
	'date_jnum13' => '13.',
	'date_jnum14' => '14.',
	'date_jnum15' => '15.',
	'date_jnum16' => '16.',
	'date_jnum17' => '17.',
	'date_jnum18' => '18.',
	'date_jnum19' => '19.',
	'date_jnum2' => '2.',
	'date_jnum20' => '20.',
	'date_jnum21' => '21.',
	'date_jnum22' => '22.',
	'date_jnum23' => '23.',
	'date_jnum24' => '24.',
	'date_jnum25' => '25.',
	'date_jnum26' => '26.',
	'date_jnum27' => '27.',
	'date_jnum28' => '28.',
	'date_jnum29' => '29.',
	'date_jnum3' => '3.',
	'date_jnum30' => '30.',
	'date_jnum31' => '31.',
	'date_jnum4' => '4.',
	'date_jnum5' => '5.',
	'date_jnum6' => '6.',
	'date_jnum7' => '7.',
	'date_jnum8' => '8.',
	'date_jnum9' => '9.',
	'date_jour_1' => 'Vasárnap',
	'date_jour_1_abbr' => 'Vas.',
	'date_jour_1_initiale' => 'V.',
	'date_jour_2' => 'Hétfő',
	'date_jour_2_abbr' => 'Hét.',
	'date_jour_2_initiale' => 'H.',
	'date_jour_3' => 'Kedd',
	'date_jour_3_abbr' => 'Kedd',
	'date_jour_3_initiale' => 'K.',
	'date_jour_4' => 'Szerda',
	'date_jour_4_abbr' => 'Sze.',
	'date_jour_4_initiale' => 'Sz.',
	'date_jour_5' => 'Csütörtök',
	'date_jour_5_abbr' => 'Csüt.',
	'date_jour_5_initiale' => 'Cs.',
	'date_jour_6' => 'Péntek',
	'date_jour_6_abbr' => 'Pént.',
	'date_jour_6_initiale' => 'P.',
	'date_jour_7' => 'Szombat',
	'date_jour_7_abbr' => 'Szo.',
	'date_jour_7_initiale' => 'Sz.',
	'date_jours' => 'nap',
	'date_minutes' => 'perc',
	'date_mois' => 'hónap',
	'date_mois_1' => 'január',
	'date_mois_10' => 'október',
	'date_mois_11' => 'november',
	'date_mois_12' => 'december',
	'date_mois_2' => 'február',
	'date_mois_3' => 'március',
	'date_mois_4' => 'április',
	'date_mois_5' => 'május',
	'date_mois_6' => 'június',
	'date_mois_7' => 'július',
	'date_mois_8' => 'augusztus',
	'date_mois_9' => 'szeptember',
	'date_saison_1' => 'tél',
	'date_saison_2' => 'tavasz',
	'date_saison_3' => 'nyár',
	'date_saison_4' => 'ősz',
	'date_semaines' => 'hét',
	'dirs_commencer' => ' ahhoz, hogy valóban kezdhesse a telepítést',
	'dirs_preliminaire' => 'Bevezetés: <b>Hozzáférési jogok beállítása</b>',
	'dirs_probleme_droits' => 'Jogosultsági hiba',
	'dirs_repertoires_absents' => 'A következő mappák nem találhatók : <ul>@bad_dirs@.</ul> </b>
  <p>Ez valószínüleg egy nagy-, kisbetűs probléma.
  Ellenőrizze, hogy a fenti mappák nagy-, és kisbetűi megfelelnek annak, ami feljebb megjelent
  ; ha mégsem, FTP szoftverével nevezze át a mappákat.
  </p><p>Ha megtörtént ez a művelet, tudni fog</p>',
	'dirs_repertoires_suivants' => '<b>A következő mappákra nincs írási jogosultsága : <ul>@bad_dirs@.</ul> </b>
  <p>Annak javítására, használja az FTP kliensét ahhoz, hogy beállítsa minden mappá hozzáférési jogait
  Az eljárás részletesen van magyarázva a telepítési kézikönyvben.
  </p><p>A megtörtént ez a művelet, tudni fogja</p>', # MODIF
	'double_occurrence' => 'Két előfordulás', # MODIF

	// E
	'envoi_via_le_site' => 'Küldés a honlapon keresztül',
	'erreur' => 'Hiba',
	'erreur_balise_non_fermee' => 'az utolsó tag nincs lezárva:',
	'erreur_texte' => 'hiba',

	// F
	'fichier_introuvable' => 'A(z) @fichier@ fájl nem található',
	'form_deja_inscrit' => 'Ön már regisztrált.',
	'form_email_non_valide' => 'A megadott e-mail cím érvénytelen.',
	'form_forum_access_refuse' => 'Önnek már nincs hozzáférése ehhez az oldalhoz.',
	'form_forum_bonjour' => 'Üdvözöljük, @nom@,',
	'form_forum_email_deja_enregistre' => 'Ez az email cím már regisztrálva van, tehát használhatja a szokásos jelszavát.',
	'form_forum_identifiant_mail' => 'Új azonosítóját elküldtük az e-mail címére.',
	'form_forum_identifiants' => 'Személyes azonosítók',
	'form_forum_indiquer_nom_email' => 'Kérjük, adja meg nevét és e-mail címét. A személyes azonosítóját e-mailben fogja megkapni.',
	'form_forum_login' => 'Login:',
	'form_forum_message_auto' => '(ez egy automatikus üzenet)',
	'form_forum_pass' => 'jelszó:',
	'form_forum_probleme_mail' => 'E-mail probléma : az azonosító nem küldhető el.',
	'form_forum_voici1' => 'Az azonosítója, amivel részt vehet a(z) "@nom_site_spip@" (@adresse_site@) oldal életében:',
	'form_forum_voici2' => 'Íme az azonosítói javasolt cikkek küldéséhez a(z)
 "@nom_site_spip@" (@adresse_login@) oldalra:',
	'form_indiquer_email' => 'Kérjük, adja meg e-mail címét.',
	'form_indiquer_nom' => 'Kérjük, adja meg a nevét.',
	'form_indiquer_nom_site' => 'Kérjük, adja meg honlapjának címét.',
	'form_pet_deja_enregistre' => 'Ezt a honlapot már regisztrálták',
	'form_pet_signature_pasprise' => 'Az Ön aláírása nincs figyelembe véve.',
	'form_prop_confirmer_envoi' => 'Erősítse meg a küldést',
	'form_prop_description' => 'Leírás/hozzászólás',
	'form_prop_enregistre' => 'A javaslatát felvettük. Nyilvánosan akkor fog megjelenni, miután e honlap adminisztrátorai jóváhagyták.',
	'form_prop_envoyer' => 'Üzenetküldés',
	'form_prop_indiquer_email' => 'Kérjük, érvényes e-mail címet adjon meg',
	'form_prop_indiquer_nom_site' => 'Kérjük, adja meg a honlap nevét.',
	'form_prop_indiquer_sujet' => 'Kérjük, adja meg a tárgyat',
	'form_prop_message_envoye' => 'Üzenet elküldve',
	'form_prop_non_enregistre' => 'A javaslatát nem rögzítettük.',
	'form_prop_sujet' => 'Tárgy',
	'form_prop_url_site' => 'Honlap címe', # MODIF
	'forum_non_inscrit' => 'Nincs regisztrálva, vagy a cím vagy a jelszó hibás.',
	'forum_par_auteur' => 'Írta: @auteur@',
	'forum_titre_erreur' => 'Hiba...',

	// I
	'ical_texte_rss_articles' => 'A honlap cikkeinek «backend» fájlja ezen a címen található:',
	'ical_texte_rss_articles2' => 'Egyaránt lehet szerezni «backend» fájlokat a honlap minden egyes rubrikának cikkeiről:',
	'ical_texte_rss_breves' => 'Ráadásul létezik olyan fájl, ami a honlap híreit tartalmazza. Egy rovatszám kijelölésével megkaphatja egyedül annak a rovatnak a híreit.',
	'icone_a_suivre' => 'Iránytű',
	'icone_admin_site' => 'Honlap adminisztrálása',
	'icone_agenda' => 'Naptár',
	'icone_aide_ligne' => 'Súgó',
	'icone_articles' => 'Cikkek',
	'icone_auteurs' => 'Szerzők',
	'icone_brouteur' => 'Gyors böngészés',
	'icone_configuration_site' => 'Konfigurálás',
	'icone_configurer_site' => 'A honlap konfigurálása',
	'icone_creer_nouvel_auteur' => 'Új szerző létrehozása',
	'icone_creer_rubrique' => 'Rovat létrehozása',
	'icone_creer_sous_rubrique' => 'Alrovat létrehozása',
	'icone_deconnecter' => 'Kijelentkezés',
	'icone_discussions' => 'Viták',
	'icone_doc_rubrique' => 'Mellékelt dokumentumok',
	'icone_ecrire_article' => 'Új cikk írása',
	'icone_edition_site' => 'Szerkesztés',
	'icone_gestion_langues' => 'Nyelvek kezelése',
	'icone_informations_personnelles' => 'Személyes adatok',
	'icone_interface_complet' => 'teljes felület',
	'icone_interface_simple' => 'egyszerűsített felület',
	'icone_maintenance_site' => 'Honlap karbantartása',
	'icone_messagerie_personnelle' => 'Személyes levelezés',
	'icone_repartition_debut' => 'Kezdettől megjeleníteni a megosztást',
	'icone_rubriques' => 'Rovatok',
	'icone_sauver_site' => 'A honlap mentése',
	'icone_site_entier' => 'Az egész honlap',
	'icone_sites_references' => 'Felvett honlapok',
	'icone_statistiques' => 'A honlap statisztikai',
	'icone_suivi_activite' => 'A honlap életének megfigyelése',
	'icone_suivi_actualite' => 'A honlap kialakulása',
	'icone_suivi_pettions' => 'Figyelni/kezelni az aláírásgyűjtéseket',
	'icone_suivi_revisions' => 'Cikkek módosítása',
	'icone_supprimer_document' => 'A dokumentum törlése',
	'icone_supprimer_image' => 'A kép törlése',
	'icone_tous_articles' => 'Az összes cikkei',
	'icone_tous_auteur' => 'Az összes szerző',
	'icone_visiter_site' => 'Látogatás', # MODIF
	'icone_voir_en_ligne' => 'Nézni élőben',
	'img_indisponible' => 'hiányzó kép',
	'impossible' => 'nem lehetséges',
	'info_a_suivre' => 'FOLYTATNI »',
	'info_acces_interdit' => 'Hozzáférés tilos',
	'info_acces_refuse' => 'Elutasított hozzáférés',
	'info_action' => 'Művelet : @action@',
	'info_administrer_rubriques' => 'Ezt a rovatot, illetve ennek alrovatait Ön adminisztrálhatja',
	'info_adresse_non_indiquee' => 'Nem jelölt tesztelendő címet !',
	'info_aide' => 'SÚGÓ :',
	'info_ajouter_mot' => 'A szó hozzáadása',
	'info_annonce' => 'HÍRDETÉS',
	'info_annonces_generales' => 'Általános hírdetések :',
	'info_article_propose' => 'Javasolt cikk',
	'info_article_publie' => 'Publikált cikk',
	'info_article_redaction' => 'Szerkeztés alatti cikk',
	'info_article_refuse' => 'Elutasított cikk',
	'info_article_supprime' => 'Törölt cikk',
	'info_articles' => 'Cikkek',
	'info_articles_a_valider' => 'Jóváhagyandó cikkek',
	'info_articles_proposes' => 'Javasolt cikkek',
	'info_auteurs_nombre' => 'szerző(k) :',
	'info_authentification_ftp' => 'Autentifikálás (FTP-vel).',
	'info_breves_2' => 'hírek',
	'info_connexion_refusee' => 'Csatlakozás tagadva',
	'info_contact_developpeur' => 'Keressen egy fejlesztőt.',
	'info_contenance' => 'A honlap tartalmazza :',
	'info_contribution' => 'Fórumi hozzászólások', # MODIF
	'info_copyright' => '@spip@ egy szabad szoftver, letölthető: @lien_gpl@.',
	'info_copyright_doc' => 'Bővebb információkra, lásd a honlapot <a href="@spipnet@">http://www.spip.net/fr</a>.', # MODIF
	'info_copyright_gpl' => 'GPL licenzú',
	'info_cours_edition' => 'Az Ön szerkesztés alatti cikkei',
	'info_creer_repertoire' => 'Hozzon létre fájlt, vagy mappát, melynek a neve :',
	'info_creer_repertoire_2' => 'az almappán <b>@repertoire@</b> belül, ezútán :',
	'info_creer_vignette' => 'a bélyegkép automatikus létrehozása',
	'info_deplier' => 'Kibontás',
	'info_descriptif_nombre' => 'Rövid ismertető(k) :',
	'info_description' => 'Leírás :',
	'info_description_2' => 'Leírás :',
	'info_dimension' => 'Méretek :',
	'info_ecire_message_prive' => 'Magán üzenet írása',
	'info_email_invalide' => 'Érvénytelen email cím.',
	'info_en_cours_validation' => 'Az Ön szerkesztés alatti cikkei',
	'info_en_ligne' => 'Jelenleg a vonalon :',
	'info_envoyer_message_prive' => 'Személyes üzenet küldés ennek a szerzőnek',
	'info_erreur_requete' => 'Hiba a lekérdezésben :',
	'info_erreur_squelette2' => 'Egyetlen csontváz (template) <b>@fichier@</b> sem áll rendelkezésre...',
	'info_erreur_systeme' => 'Rendszer hiba (errno @errsys@)',
	'info_erreur_systeme2' => 'A merevlemez talán tele van, vagy megsérült az adatbázis.<br />
<span style="color:red;">probáljon <a href=\'@script@\'>javítani az adatbázis</a>, vagy keresse fel a rendszergazdát.</span>', # MODIF
	'info_fini' => 'Készen van !',
	'info_format_image' => 'Használható képformátumok a bélyegképek készítésére : @gd_formats@.',
	'info_format_non_defini' => 'Határozatlan formátum',
	'info_grand_ecran' => 'Nagy képernyő',
	'info_image_aide' => 'SÚGÓ',
	'info_image_process_titre' => 'Bélyegképek készítési módszer',
	'info_impossible_lire_page' => '<b>Hiba !</b> Az opdal nem olvasható  <tt><html>@test_proxy@</html></tt> a proxyn keresztül <tt>', # MODIF
	'info_installation_systeme_publication' => 'A publikálási rendszer telepítése...',
	'info_installer_documents' => 'Automatikusan telepítheti az összes dokumentumot, amit tartalmaz az @upload@ nevű mappa.',
	'info_installer_ftp' => 'Mint adminisztrátor, az @upload@ mappába másolhat (FTP-vel) fájlokat, és később közvetlenül kijelölheti őket itt.',
	'info_installer_images' => 'JPEG, GIF és PNG tipusú képek telepíthetők.',
	'info_installer_images_dossier' => 'Képeket másolni a @upload@ mappába ahhoz, hogy itt lehessen kijelölni.',
	'info_interface_complete' => 'teljes felület',
	'info_interface_simple' => 'Egyszerűsített felület',
	'info_joindre_document_article' => 'Olyan tipusú dokumentumokat csatolhat ehhez a cikkhez',
	'info_joindre_document_rubrique' => 'Olyan tipusú dokumentumokat beszúrhat abba a rovatba',
	'info_joindre_documents_article' => 'Olyan tipusú dokumentumok csatolhatók az Ön cikkéhez :',
	'info_l_article' => 'a cikk',
	'info_la_breve' => 'a hír',
	'info_la_rubrique' => 'a rovat',
	'info_langue_principale' => 'A honlap alapnyelve',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixel',
	'info_les_auteurs_1' => 'írta @les_auteurs@',
	'info_logo_format_interdit' => 'Csak a @formats@ tipusú formatumak vannak engedlyezve.',
	'info_logo_max_poids' => 'Egy logo kisebb legyen, mint @maxi@ (ez a fájl pedig @actuel@).',
	'info_mail_fournisseur' => 'önmaga@szolgaltato.com',
	'info_message_2' => 'ÜZENET',
	'info_message_supprime' => 'ÜZENET TÖRÖLVE',
	'info_mise_en_ligne' => 'Publikálás időpontja :',
	'info_modification_parametres_securite' => 'biztonsági paraméterek módosítása',
	'info_mois_courant' => 'A hónap folyamán :',
	'info_mot_cle_ajoute' => 'A következő kulcsszó nem lett hozzátéve',
	'info_multi_herit' => 'Alapértelmezett nyelv',
	'info_multi_langues_soulignees' => 'Az <u>aláhuzott nyelveknek</u> van fordítása a felület összes szövegére. Ha ezeket jelöli ki, akkor a nyilvános honlap számos elemei (dátumok, űrlapok) lesznek automatikusan lefordítva. A nem aláhúzott nyelvekre pedig azok az elemek a honlap alapnyelvén fognak megjelenni.', # MODIF
	'info_multilinguisme' => 'Többnyelvűség',
	'info_nom_non_utilisateurs_connectes' => 'Az Ön neve nem szerepel a jelenleg csatlakozott felhasználók listájában',
	'info_nom_utilisateurs_connectes' => 'Az Ön neve szerepel a jelenleg csatlakozott felhasználók listájában.',
	'info_nombre_en_ligne' => 'Jelenleg a vonalon :',
	'info_non_resultat' => 'Nincs találat erre "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Nem használja a honlap belső levelezését.',
	'info_nouveau_message' => 'ÖNNEK ÚJ ÜZENETE VAN',
	'info_nouveaux_messages' => 'ÖNNEK @total_messages@ ÚJ ÜZENETE VAN',
	'info_numero_abbreviation' => 'sz. ',
	'info_pense_bete' => 'EMLÉKEZTET?',
	'info_petit_ecran' => 'Kisebb képerny?',
	'info_petition_close' => 'Kérelem lezárva',
	'info_pixels' => 'pixelek',
	'info_plusieurs_mots_trouves' => 'Néhany kulcsszó talált azzal "@cherche_mot@":',
	'info_portfolio_automatique' => 'Automatikus portfolio :',
	'info_premier_resultat' => '[@debut_limit@ első eredmények, @total@ összesen]',
	'info_premier_resultat_sur' => '[@debut_limit@ eredmény, összesen @total@]',
	'info_propose_1' => '[@nom_site_spip@] ezt javasolta : @titre@',
	'info_propose_2' => 'Javasolt cikk
---------------',
	'info_propose_3' => 'A "@titre@" című cikket javasolták publikálásra.',
	'info_propose_4' => 'Kérjuk, konzultálja és adjon róla véleményét',
	'info_propose_5' => 'a hozzá kapcsolódó fórumban. Elérhető a következő címen :',
	'info_publie_01' => 'A "@titre@" című cikket @connect_nom@ hagyta jóvá.',
	'info_publie_1' => '[@nom_site_spip@] PUBLIKÁLJA : @titre@',
	'info_publie_2' => 'Publikált cikkek
--------------',
	'info_rechercher' => 'Keresés',
	'info_rechercher_02' => 'Keresés :',
	'info_remplacer_vignette' => 'Az alapértelmezett bélyegkép helyettesítése egy személyes logoval :',
	'info_sans_titre_2' => 'cím nélkül',
	'info_selectionner_fichier' => 'Kijelölhet egy fájlt az @upload@ mappából',
	'info_selectionner_fichier_2' => 'Válasszon egy fájlt :',
	'info_supprimer_vignette' => 'a bélyegkép törlése',
	'info_symbole_bleu' => 'A <b>kék</b> jel <b>emlékeztetőt</b> jelez: vagyis egy személyes jellegű üzenetet.', # MODIF
	'info_symbole_jaune' => 'A <b>sárga</b> jel <b>minden szerzőnek szóló hírt</b> jelez : minden adminisztrátor módosíthatja, és minden szerző láthatja.', # MODIF
	'info_symbole_vert' => 'A <b>zöld</b> jel a honlap <b>többi felhasználóival cserélt üzeneteket</b> jelzi.', # MODIF
	'info_telecharger_nouveau_logo' => 'Új logo feltöltése :',
	'info_telecharger_ordinateur' => 'Feltöltés a gépéről :',
	'info_tous_resultats_enregistres' => '[minden eredmény mentve]',
	'info_tout_afficher' => 'Mindent megjelenít',
	'info_travaux_texte' => 'Ez a honlap még nincs konfigurálva. Jöjjön vissza később...',
	'info_travaux_titre' => 'A honlap javítás alatt van',
	'info_trop_resultat' => 'Túl sok eredmény erre "@cherche_mot@" ; Szükítse a kérésést.',
	'info_utilisation_messagerie_interne' => 'A honlap belső levelezőrendszerét használhatja.',
	'info_valider_lien' => 'a link jóváhagyása',
	'info_verifier_image' => ', elenőrizze, hogy a képek megfelelően lettek másolva.',
	'info_vignette_defaut' => 'Alapértelmezett bélyegkép',
	'info_vignette_personnalisee' => 'Személyes bélyegkép',
	'info_visite' => 'látogatás :',
	'info_vos_rendez_vous' => 'A leendő találkozói',
	'infos_vos_pense_bete' => 'Az Ön emlékeztetői', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Csak az ikonok megjelenítése',
	'lien_afficher_texte_icones' => 'Ikonok és szöveg megjelenítése',
	'lien_afficher_texte_seul' => 'Csak a szöveg megjelenítése',
	'lien_liberer' => 'szabadítani',
	'lien_liberer_tous' => 'a cikkek szabadítása', # MODIF
	'lien_nouvea_pense_bete' => 'ÚJ EMLÉKEZTETŐ',
	'lien_nouveau_message' => 'ÚJ ÜZENET',
	'lien_nouvelle_annonce' => 'ÚJ HÍRKÖZLÉS',
	'lien_petitions' => 'ALÁÍRÁSGYŰJTÉS',
	'lien_popularite' => 'népszerűség : @popularite@%',
	'lien_racine_site' => 'HONLAP TETEJE',
	'lien_reessayer' => 'újabb próba',
	'lien_repondre_message' => 'Válaszolni az üzenetre',
	'lien_supprimer' => 'töröl',
	'lien_tout_afficher' => 'Mindent megjelenít',
	'lien_visite_site' => 'a honlap látógatása',
	'lien_visites' => '@visites@ látógatás',
	'lien_voir_auteur' => 'Lásd a szerzőt',
	'ligne' => 'Sor',
	'login' => 'Kapcsolat',
	'login_acces_prive' => 'Belépés a privát részbe',
	'login_autre_identifiant' => 'Csatlakozás másik azonosítóval',
	'login_cookie_accepte' => 'Állítsa be a böngészőjét úgy, hogy elfogadja őket(legalább ezen a honlapon).',
	'login_cookie_oblige' => 'A honlaphoz való biztonságos azonosítás érdekében a sütiket (cookies) el kell fogadni.',
	'login_deconnexion_ok' => 'Kijelentkezés megtörtént.',
	'login_erreur_pass' => 'Hibás jelszó.',
	'login_espace_prive' => 'privát rész',
	'login_identifiant_inconnu' => 'A « @login@ » azonosító ismeretlen.',
	'login_login' => 'Login :',
	'login_login2' => 'Login (honlaphoz való csatlakozási azonosító) :', # MODIF
	'login_login_pass_incorrect' => '(Érvénytelen login vagy jelszó.)',
	'login_motpasseoublie' => 'a jelszót elfelejtette ?',
	'login_non_securise' => 'Vigyázat, az űrlap nem biztonságos.
   Ha nem akarja, hogy jelszavát kaphassák a hálozaton, akkor a Javascriptet aktiválja
   a böngészójében és',
	'login_nouvelle_tentative' => 'Újabb kisérlet',
	'login_par_ici' => 'Be van íratkozva... errefelé...',
	'login_pass2' => 'Jelszó :',
	'login_preferez_refuser' => '<b>Ha mégis elutasítja a sütiket (cookies)</b>, akkor egy másik csatlakozási módszer (kevésbé biztonságos) áll rendelkezésére :',
	'login_recharger' => 'újra tölteni az oldalt',
	'login_rester_identifie' => 'Azonosítva maradni pár napig',
	'login_retour_public' => 'Vissza a nyilvános honlapra',
	'login_retour_site' => 'Vissza a nyilvános honlapra',
	'login_retoursitepublic' => 'vissza a nyilvános honlapra',
	'login_sinscrire' => 'beíratkozás',
	'login_test_navigateur' => 'böngésző teszt/újracsatlakozás',
	'login_verifiez_navigateur' => '(Azonban ellenőrizze, hogy a bongészó nem memorizálta-e a jelszót...)',

	// M
	'masquer_colonne' => 'Oszlop elrejtése',
	'masquer_trad' => 'fordítások elrejtése',
	'module_fichiers_langues' => 'Nyelvi fájlok',

	// N
	'navigateur_pas_redirige' => 'Ha a böngészó nincsen átirányítva, akkor ide kattintson.',
	'numero' => 'Szám',

	// O
	'occurence' => 'Előfordulás',
	'onglet_affacer_base' => 'Adatbázis törlése',
	'onglet_auteur' => 'A szerző',
	'onglet_contenu_site' => 'A honlap tartalma',
	'onglet_evolution_visite_mod' => 'Kialakulás',
	'onglet_fonctions_avances' => 'Bővített funkciók',
	'onglet_informations_personnelles' => 'Személyes adatok',
	'onglet_interactivite' => 'Interaktivitás',
	'onglet_messagerie' => 'Levelezés',
	'onglet_repartition_rubrique' => 'Rovat szerinti bontás',
	'onglet_save_restaur_base' => 'Adatbázis mentése/resztaurálása',
	'onglet_vider_cache' => 'Cache ürítése',

	// P
	'pass_choix_pass' => 'Legyen szíves választani az új jelszavát :',
	'pass_erreur' => 'Hiba',
	'pass_erreur_acces_refuse' => '<b>Hiba :</b> már nincs hozzáférése arra a honlapra.',
	'pass_erreur_code_inconnu' => '<b>Hiba :</b> ez a kód a honlap egyik engedélyezett felhasználójanak sem felel meg.',
	'pass_erreur_non_enregistre' => '<b>Hiba :</b> a cím <tt>@email_oubli@</tt> nincs felvéve ezen a honlapon.',
	'pass_erreur_non_valide' => '<b>Hiba :</b> ez az email <tt>@email_oubli@</tt> érvénytelen !',
	'pass_erreur_probleme_technique' => '<b>Hiba :</b> műszaki okból, az email nem küldhető el.',
	'pass_espace_prive_bla' => 'A privát rész nyított a
  látógatók részére, miután beíratkoztak. Ha be van iratkozva,
 akkor megtekintheti a szerkesztés alatti cikkeket,
 javasolhat cikkeket és részt vehet a fórumokban.',
	'pass_forum_bla' => 'Hozzászólást kért olyan fórumon, ami a beiratkozott látógatóknak van fenntartva.',
	'pass_indiquez_cidessous' => 'Lejjebb jelezze az email címet, amivel beíratkozott az imént. Olyan
   emailt fog kapni, ami mutatja az eljárást az Ön hozzáférésének visszaszerzésére.',
	'pass_mail_passcookie' => '(Ez egy automatikus üzenet)
A @nom_site_spip@ (@adresse_site@)
honlaphozzáférés visszaszerzésére
Menjen a következő címre :

    @sendcookie@

Akkor újabb jelszót tud beírni
és újra csatlakozhat a honlapra.

',
	'pass_mot_oublie' => 'Elfelejtett jelszó',
	'pass_nouveau_enregistre' => 'Az új jelszava fel lett véve.',
	'pass_nouveau_pass' => 'Új jelszó',
	'pass_ok' => 'Rendben',
	'pass_oubli_mot' => 'Jelszó elvesztése',
	'pass_quitter_fenetre' => 'Kilépni az ablakból',
	'pass_rappel_login' => 'Emlékeztető : az Ön azonosítója (login) « @login@ ».',
	'pass_recevoir_mail' => 'Hamarosan olyan emailt fog kapni, ami mutatja hogyan lehet visszaszerezni a hozzáférést a honlapra.',
	'pass_retour_public' => 'Vissza a nyilvános honlapra',
	'pass_rien_a_faire_ici' => 'Nincs keresnivalója itt.',
	'pass_vousinscrire' => 'Beíratkozás ezen a honlapon',
	'precedent' => 'elöző',
	'previsualisation' => 'Előnézet',
	'previsualiser' => 'Előnézet',

	// R
	'retour' => 'Vissza',

	// S
	'spip_conforme_dtd' => 'A SPIP szerint ez az oldal teljesíti a DOCTYPE követelményeit:',
	'squelette' => 'vázlat',
	'squelette_inclus_ligne' => 'vázlatot beleértve, sor',
	'squelette_ligne' => 'vázlat, sor',
	'stats_visites_et_popularite' => '@visites@ látogatás ; népszerűség : @popularite@',
	'suivant' => 'következő',

	// T
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ byte',
	'texte_actualite_site_1' => 'Ha barátkozik a felülettel akkor kattintson arra «',
	'texte_actualite_site_2' => 'teljes felület',
	'texte_actualite_site_3' => '» több lehetőség megnyítására.',
	'texte_creation_automatique_vignette' => 'A bélyegképek automatikus létrehozása aktiválva van a honlapon. Ha erről az űrlapról telepít @gd_formats@ formátumú képeket, akkor majd bélyegkép kiséri, melynek maximális mérete @taille_preview@ pixel.',
	'texte_documents_associes' => 'A következő dokumentumok tartoznak a cikk,
    de nem lettek közvetlenül
   beszúrva. A nyilvános rész oldalbeállítása szerint,
  csatolt dokumentumok formában jelenhetnek meg.',
	'texte_erreur_mise_niveau_base' => 'Adatbázis hiba verziófrissítéskor.
  A <b>@fichier@</b> kép nem ment át (@id_article@ cikk).
 Jegyezze meg ezt a nevet, próblája újra a frissítést, és végül ellenőrizze, hogy a képek mindig jelennek meg a cikkekben.', # MODIF
	'texte_erreur_visiteur' => 'Olyan azonosítóval próbált hozzáférni a privát zónához, aminek ehhez nincs jogosultsága.',
	'texte_inc_auth_1' => 'Ön a <b>@auth_login@</b> loginnal
van azonosítva, nem ez létezik/létezett az adatbázisban. 
Próbáljon', # MODIF
	'texte_inc_auth_2' => 'újra csatlakozni',
	'texte_inc_auth_3' => ', miután esetleg bezárta és 
újraindította a böngészőjét.',
	'texte_inc_config' => 'Az ezeken az oldalokon végzett módosítások jelentősen befolyásolják a
 honlap működését. Javasoljuk, hogy ne  avatkozzon bele, amig Ön nem járátos
 az SPIP működésében. <br /><br /><b>Általában nagyon tanácsos bízni ezeket az oldalakat
 a honlap fő webmesterére.</b>', # MODIF
	'texte_inc_meta_1' => 'A rendszer hibát észlelt a <code>@fichier@</code> fájl írásákor. Mint honlap adminisztrátor, legyen szíves',
	'texte_inc_meta_2' => 'ellenőrizni a irási jogokat',
	'texte_inc_meta_3' => 'a <code>@repertoire@</code> nevű mappán.',
	'texte_statut_en_cours_redaction' => 'szerkesztés alatt',
	'texte_statut_poubelle' => 'szemetesbe',
	'texte_statut_propose_evaluation' => 'felmérésre javasolt',
	'texte_statut_publie' => 'publikált',
	'texte_statut_refuse' => 'elutasított',
	'titre_ajouter_mot_cle' => 'KULCSSZÓ HOZZÁADÁS :',
	'titre_cadre_raccourcis' => 'GYORS HIVATKOZÁSOK :',
	'titre_changer_couleur_interface' => 'Felület színe változtatása',
	'titre_image_admin_article' => 'Ezt a cikket Ön adminisztrálhatja',
	'titre_image_administrateur' => 'Adminisztrátor',
	'titre_image_aide' => 'Súgó erről a részről',
	'titre_image_auteur_supprime' => 'Szerző törölve',
	'titre_image_redacteur' => 'Hozzáférés nélküli szerző',
	'titre_image_redacteur_02' => 'Szerző',
	'titre_image_visiteur' => 'Vendég',
	'titre_joindre_document' => 'DOKUMENTUM CSATOLÁSA',
	'titre_mots_cles' => 'KULCSSZAVAK',
	'titre_probleme_technique' => 'Vigyázat : műszaki hiba (SQL szerver) miatt nincs hozzáférés erre a részre. Megértését köszönjük.', # MODIF
	'titre_publier_document' => 'DOKUMENTUM PUBLIKÁLÁSA ABBAN A ROVATBAN',
	'titre_signatures_attente' => 'Érvényesítésre várakozó aláírások',
	'titre_signatures_confirmees' => 'Érvényesített aláírások',
	'titre_statistiques' => 'A honlap statisztikai',
	'titre_titre_document' => 'Dokumentum címe :',
	'trad_reference' => '(eredeti cikk)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : B jelző után',
	'zbug_balise_inexistante' => 'hiba @from@: a(z) #@balise@ tag nem létezik', # MODIF
	'zbug_balise_sans_argument' => 'Hiányzó argumentum a(z) @balise@ tagban',
	'zbug_boucle' => 'folyamat',
	'zbug_boucle_recursive_undef' => 'határozatlan rekurzív folyamat', # MODIF
	'zbug_calcul' => 'számolás',
	'zbug_champ_hors_boucle' => 'A @champ@ mező a folyamaton kívül van',
	'zbug_champ_hors_motif' => 'A @champ@ mező egy @motif@ jellegű folyamaton kívül van', # MODIF
	'zbug_code' => 'kód',
	'zbug_critere_inconnu' => 'ismeretlen kritérium @critere@', # MODIF
	'zbug_distant_interdit' => 'külső tilos', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'duplumokat használt egy táblán, amin nincs egyszerű elsődleges kulcs', # MODIF
	'zbug_doublon_table_sans_index' => 'index nélküli duplumok egy táblában', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@: dupla definició', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: záró tag hiányzik', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Folyamat szintáxisa nem korrekt', # MODIF
	'zbug_erreur_compilation' => 'Összeállítási hiba',
	'zbug_erreur_execution_page' => 'futtatási hiba az oldalnál', # MODIF
	'zbug_erreur_filtre' => 'Hiba : szűrő <b>« @filtre@ »</b> nincs meghatározva', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} csak a (FORUMS) vagy (RUBRIQUES) folyamatoknál alkalmazható', # MODIF
	'zbug_erreur_squelette' => 'Hiba a vázban',
	'zbug_hors_compilation' => 'Nincs összeállítva',
	'zbug_info_erreur_squelette' => 'Hiba a honlapon',
	'zbug_inversion_ordre_inexistant' => 'nem létező sorrend megfordítása', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION tag {pagination} kritérium nélkül, vagy rekurzív ismétlésben használta', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Hibás inkluziós parameterek', # MODIF
	'zbug_profile' => 'Számolás hossza: @time@',
	'zbug_resultat' => 'eredmény',
	'zbug_serveur_indefini' => 'határozatlan SQL szerver', # MODIF
	'zbug_statistiques' => 'SQL kérések statisztikája hossz szerint',
	'zbug_table_inconnue' => 'A « @table@ » nevű SQL tábla ismeretlen',
	'zxml_connus_attributs' => 'ismert tulajdonságok',
	'zxml_de' => 'Innen:',
	'zxml_inconnu_attribut' => 'ismeretlen tulajdonság',
	'zxml_inconnu_balise' => 'ismeretlen tag',
	'zxml_inconnu_entite' => 'ismeretlen bejegyzés',
	'zxml_inconnu_id' => 'ismeretlen ID',
	'zxml_mais_de' => 'de innen:',
	'zxml_non_conforme' => 'nem érvényes az alapelvre',
	'zxml_non_fils' => 'nem a gyermeke neki:',
	'zxml_nonvide_balise' => 'a tag nem üres',
	'zxml_obligatoire_attribut' => 'szükséges tulajdonság hiányzik ebben:',
	'zxml_succession_fils_incorrecte' => 'hibás öröklés',
	'zxml_survoler' => 'a helyesek megjelenítéséhez mozgassa föléjük az egeret',
	'zxml_valeur_attribut' => 'tulajdonság értéke',
	'zxml_vide_balise' => 'üres tag',
	'zxml_vu' => 'látva ezelőtt:'
);

?>
